@@ -4,9 +4,10 @@ docstring
 from __future__ import annotations
 
 import json
-
+import base64
 import requests
 import os
+import base64
 from collections import defaultdict
 
 from typing import (
@@ -29,6 +30,8 @@ from .type import (
     FileBoxOptionsBase,
     Metadata, FileBoxType)
 
+from wechaty_puppet.exceptions import WechatyPuppetConfigurationError
+
 
 class FileBoxEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -65,13 +68,20 @@ class FileBox:
 
         elif isinstance(options, FileBoxOptionsStream):
             # TODO -> need to get into detail for stream sending
-            pass
+            self.stream = options.stream
 
         elif isinstance(options, FileBoxOptionsQrCode):
             self.qrCode = options.qr_code
 
         elif isinstance(options, FileBoxOptionsBase64):
-            self.base64 = options.base64
+            self.base64: bytes
+            if isinstance(options.base64, str):
+                self.base64 = str.encode(options.base64)
+            elif isinstance(options.base64, bytes):
+                self.base64 = options.base64
+            else:
+                raise WechatyPuppetConfigurationError(
+                    f'Base64 File Data Type is invalid, str/bytes is supported')
 
     @property
     def metadata(self) -> dict:
@@ -149,7 +159,8 @@ class FileBox:
         save the content to the file
         :return:
         """
-        if self.type() == FileBoxType.Url:
+        file_box_type = self.type()
+        if file_box_type == FileBoxType.Url:
             if not self.mimeType or not self.name:
                 await self.sync_remote_name()
 
@@ -159,7 +170,6 @@ class FileBox:
             raise FileExistsError(f'FileBox.toFile(${file_path}): file exist. '
                                   f'use FileBox.toFile(${file_path}, true) to '
                                   f'force overwrite.')
-        file_box_type = self.type()
 
         if file_box_type == FileBoxType.Buffer:
             with open(file_path, 'wb+') as f:
@@ -177,6 +187,15 @@ class FileBox:
                 img = qrcode.make(self.qrCode)
                 img.get_image().save(f)
 
+        elif file_box_type == FileBoxType.Base64:
+            data = base64.b64decode(self.base64)
+            with open(file_path, 'wb') as f:
+                f.write(data)
+
+        elif file_box_type == FileBoxType.Stream:
+            with open(file_path, 'wb+') as f:
+                f.write(self.stream)
+
     def to_base64(self) -> str:
         """
         transfer file-box to base64 string
@@ -199,18 +218,24 @@ class FileBox:
         return cls(options)
 
     @classmethod
-    def from_file(cls: Type[FileBox], path: str, name: Optional[str]
+    def from_file(cls: Type[FileBox], path: str, name: Optional[str] = None
                   ) -> FileBox:
         """
         create file-box from file
+
+        2020.08.16 -> hostie-server don't support file type, so we will change
+            this FileBox type to base64 default
         """
         if not os.path.exists(path):
             raise FileNotFoundError(f'{path} file not found')
         if name is None:
             name = os.path.basename(path)
 
-        options = FileBoxOptionsFile(name=name, path=path)
-        return cls(options)
+        with open(path, 'rb') as f:
+            content = base64.b64encode(f.read())
+
+        # to make `from_file` run well temporary
+        return cls.from_base64(base64=content, name=name)
 
     @classmethod
     def from_stream(cls: Type[FileBox], stream: bytes, name: str) -> FileBox:
@@ -233,7 +258,7 @@ class FileBox:
         return cls(options)
 
     @classmethod
-    def from_base64(cls: Type[FileBox], base64: str, name: str) -> FileBox:
+    def from_base64(cls: Type[FileBox], base64: bytes, name: str) -> FileBox:
         """
         create file-box from base64 str
 
@@ -253,7 +278,7 @@ class FileBox:
         example value: dataURL: `data:image/png;base64,${base64Text}`,
         """
         return cls.from_base64(
-            data_url_to_base64(data_url),
+            str.encode(data_url_to_base64(data_url)),
             name
         )
 
